@@ -13,9 +13,8 @@ distributed under the License is distributed on an
 ANY KIND, either express or implied.
 """
 from datetime import datetime
-from os import makedirs, rmdir, remove
-from os.path import join
-from shutil import rmtree
+from os import makedirs, listdir
+from os.path import join, splitext
 
 import pytest
 import json
@@ -27,9 +26,6 @@ from ..reader import Reader
 from ..xml_files import XML
 
 
-CACHE_DIR = '.cache'
-
-
 def test_writer_receives_bad_init_data():
     """Test bin writer fails when initialized with non-int sampling rate"""
     BinWriter(100)
@@ -38,20 +34,17 @@ def test_writer_receives_bad_init_data():
     assert str(exc_info.value) == "Sampling rate not int. Received 100.0"
 
 
-def test_writer_doesnt_overwrite():
-    """test that `mffpy.Writer` doesn't overwrite existing files"""
-    dirname = join(CACHE_DIR, 'testdir.mff')
+def test_writer_doesnt_overwrite(tmpdir):
+    """test that `mffpy.Writer` doesn't overwrite existing files by default"""
+    dirname = join(str(tmpdir), 'testdir.mff')
     makedirs(dirname, exist_ok=True)
-    with pytest.raises(AssertionError) as exc_info:
+    with pytest.raises(AssertionError, match='File.*exists already'):
         Writer(dirname)
-    assert str(exc_info.value) == "File '.cache/testdir.mff' exists already"
-
-    rmdir(dirname)
 
 
-def test_writer_writes():
+def test_writer_writes(tmpdir):
     """Test `mffpy.Writer` can write binary and xml files"""
-    dirname = join(CACHE_DIR, 'testdir2.mff')
+    dirname = join(str(tmpdir), 'testdir2.mff')
     # create some data and add it to a binary writer
     device = 'HydroCel GSN 256 1.0'
     num_samples = 10
@@ -80,23 +73,101 @@ def test_writer_writes():
     layout = R.directory.filepointer('sensorLayout')
     layout = XML.from_file(layout)
     assert layout.name == device
-    # cleanup
-    try:
-        remove(join(dirname, 'info.xml'))
-        remove(join(dirname, 'info1.xml'))
-        remove(join(dirname, 'epochs.xml'))
-        remove(join(dirname, 'signal1.bin'))
-        remove(join(dirname, 'coordinates.xml'))
-        remove(join(dirname, 'sensorLayout.xml'))
-        rmdir(dirname)
-    except BaseException:
-        raise AssertionError(f"""
-        Clean-up failed of '{dirname}'.  Were additional files written?""")
 
 
-def test_writer_writes_multple_bins():
+def test_writer_can_overwrite(tmpdir):
+    """test that the Writer does overwrite existing files"""
+    dirname = join(str(tmpdir), 'testdir2.mff')
+    # create some data and add it to a binary writer
+    device = 'HydroCel GSN 256 1.0'
+    num_samples = 10
+    num_channels = 256
+    sampling_rate = 128
+    b = BinWriter(sampling_rate=sampling_rate, data_type='EEG')
+    data = np.random.randn(num_channels, num_samples).astype(np.float32)
+    b.add_block(data)
+    # create an mffpy.Writer and add a file info, and the binary file
+    W = Writer(dirname)
+    startdatetime = datetime.strptime(
+        '1984-02-18T14:00:10.000000+0100', XML._time_format)
+    W.addxml('fileInfo', recordTime=startdatetime)
+    W.add_coordinates_and_sensor_layout(device)
+    W.addbin(b)
+    W.write()
+
+    # list files
+    files = listdir(dirname)
+    assert 'info.xml' in files
+    assert 'coordinates.xml' in files
+    assert 'sensorLayout.xml' in files
+
+    # add a directory inside
+    makedirs(join(dirname, 'test'))
+
+    # create new writer to overwrite
+    b = BinWriter(sampling_rate=sampling_rate, data_type='EEG')
+    data2 = np.random.randn(num_channels, num_samples).astype(np.float32)
+    b.add_block(data2)
+    W = Writer(dirname, overwrite=True)
+    W.addbin(b)
+    W.write()
+
+    # compare files with
+    files = listdir(dirname)
+    assert 'info.xml' not in files
+    assert 'coordinates.xml' not in files
+    assert 'sensorLayout.xml' not in files
+    assert 'test' not in files
+
+    # read
+    R = Reader(dirname)
+    with pytest.raises(FileNotFoundError):
+        R.startdatetime
+    with pytest.raises(FileNotFoundError):
+        R.directory.filepointer('sensorLayout')
+    read_data = R.get_physical_samples_from_epoch(R.epochs[0])
+    assert 'EEG' in read_data
+    read_data, t0 = read_data['EEG']
+    assert t0 == 0.0
+    assert np.allclose(read_data, data2)
+    assert not np.allclose(read_data, data)
+
+    # test writer can 'overwrite' if there is nothing to overwrite
+    dirname = join(str(tmpdir), 'testdir3.mff')
+    W = Writer(dirname, overwrite=True)
+    W.addbin(b)
+    W.write()
+
+
+def test_overwrite_mfz(tmpdir):
+    """Test mffdir and mfz file are overwritten when overwrite is on"""
+    mfzpath = join(tmpdir, 'test.mfz')
+    mffpath = splitext(mfzpath)[0] + '.mff'
+    time1 = datetime.strptime('1984-02-18T14:00:10.000000+0100',
+                              "%Y-%m-%dT%H:%M:%S.%f%z")
+    time2 = datetime.strptime('1973-10-23T14:00:10.000000+0100',
+                              "%Y-%m-%dT%H:%M:%S.%f%z")
+
+    W1 = Writer(mfzpath)
+    W1.addxml('fileInfo', recordTime=time1)
+    W1.write()
+
+    for p in [mffpath, mfzpath]:
+        R1 = Reader(p)
+        assert R1.startdatetime == time1
+
+    W2 = Writer(mfzpath, overwrite=True)
+    W2.addxml('fileInfo', recordTime=time2)
+    W2.write()
+
+    for p in [mffpath, mfzpath]:
+        R2 = Reader(p)
+        assert R2.startdatetime == time2
+
+
+def test_writer_writes_multple_bins(tmpdir):
     """test that `mffpy.Writer` can write multiple binary files"""
-    dirname = join(CACHE_DIR, 'multiple_bins.mff')
+    dirname = join(str(tmpdir), 'multiple_bins.mff')
     device = 'HydroCel GSN 256 1.0'
     # create some data and add it to binary writers
     num_samples = 10
@@ -140,20 +211,6 @@ def test_writer_writes_multple_bins():
     layout = R.directory.filepointer('sensorLayout')
     layout = XML.from_file(layout)
     assert layout.name == device
-    # cleanup
-    try:
-        remove(join(dirname, 'info.xml'))
-        remove(join(dirname, 'info1.xml'))
-        remove(join(dirname, 'signal1.bin'))
-        remove(join(dirname, 'info2.xml'))
-        remove(join(dirname, 'signal2.bin'))
-        remove(join(dirname, 'epochs.xml'))
-        remove(join(dirname, 'coordinates.xml'))
-        remove(join(dirname, 'sensorLayout.xml'))
-        rmdir(dirname)
-    except BaseException:
-        raise AssertionError(f"""
-        Clean-up failed of '{dirname}'.  Were additional files written?""")
 
 
 def test_write_multiple_blocks():
@@ -172,7 +229,7 @@ def test_write_multiple_blocks():
 
 def test_writer_is_compatible_with_egi():
     """check that binary writers fail to write EGI-incompatible files"""
-    filename = join('.cache', 'unimportant-filename.mff')
+    filename = 'unimportant-filename.mff'
     bin_writer = BinWriter(sampling_rate=128, data_type='PNSData')
     writer = Writer(filename)
     message = "Writing type 'PNSData' to 'signal1.bin' may be " \
@@ -187,8 +244,8 @@ def test_writer_is_compatible_with_egi():
     assert str(exc_info.value) == message
 
 
-def test_writer_exports_JSON():
-    filename = 'test1.json'
+def test_writer_exports_JSON(tmpdir):
+    filename = join(str(tmpdir), 'test1.json')
     # Root tags corresponding to available XMLType sub-classes
     xml_root_tags = ['fileInfo', 'dataInfo', 'patient', 'sensorLayout',
                      'coordinates', 'epochs', 'eventTrack', 'categories',
@@ -207,26 +264,20 @@ def test_writer_exports_JSON():
     with open(filename) as file:
         data = json.load(file)
     assert data == content
-    # cleanup
-    try:
-        remove(filename)
-    except BaseException:
-        raise AssertionError(f"""Clean-up failed of '{filename}'.""")
 
 
-def test_streaming_writer_receives_bad_init_data():
+def test_streaming_writer_receives_bad_init_data(tmpdir):
     """Test bin writer fails when initialized with non-int sampling rate"""
-    dirname = join(CACHE_DIR, 'testdir.mff')
+    dirname = join(str(tmpdir), 'testdir.mff')
     makedirs(dirname)
     StreamingBinWriter(100, mffdir=dirname)
     with pytest.raises(AssertionError) as exc_info:
         StreamingBinWriter(100.0, mffdir=dirname)
     assert str(exc_info.value) == "Sampling rate not int. Received 100.0"
-    rmtree(dirname)
 
 
-def test_streaming_writer_writes():
-    dirname = join(CACHE_DIR, 'testdir3.mff')
+def test_streaming_writer_writes(tmpdir):
+    dirname = join(str(tmpdir), 'testdir3.mff')
     # create some data and add it to a binary writer
     device = 'HydroCel GSN 256 1.0'
     num_samples = 10
@@ -257,9 +308,3 @@ def test_streaming_writer_writes():
     layout = reader.directory.filepointer('sensorLayout')
     layout = XML.from_file(layout)
     assert layout.name == device
-    # cleanup
-    try:
-        rmtree(dirname)
-    except BaseException:
-        raise AssertionError(f"""
-        Clean-up failed of '{dirname}'.  Were additional files written?""")
