@@ -1,6 +1,6 @@
 import logging
 import warnings
-import xml.etree.ElementTree as ET
+from lxml import etree as ET
 from datetime import datetime
 from collections import defaultdict
 import numpy as np
@@ -65,14 +65,19 @@ class XMLType(type):
             return False
 
     @classmethod
-    def from_file(typ, filepointer: FilePointer):
+    def from_file(typ, filepointer: FilePointer, recover: bool = True):
         """return new `XMLType` instance of the appropriate sub-class
 
         **Parameters**
         *filepointer*: str or IO[bytes]
             pointer to the xml file
+        *recover*: bool
+            indicates whether to try hard to parse through broken XML or not.
+            Set to `True` by default because it's necessary if there are weird
+            characters in the xml file, which can occasionally occur.
         """
-        xml_root = ET.parse(filepointer).getroot()
+        parser = ET.XMLParser(recover=recover)
+        xml_root = ET.parse(filepointer, parser).getroot()
         return typ._registry[xml_root.tag](xml_root)
 
     @classmethod
@@ -125,11 +130,11 @@ class XML(metaclass=XMLType):
         return txt[:-2] + ':' + txt[-2:]
 
     def find(self, tag, root=None):
-        root = root or self.root
+        root = self.root if root is None else root
         return root.find(self._xmlns+tag)
 
     def findall(self, tag, root=None):
-        root = root or self.root
+        root = self.root if root is None else root
         return root.findall(self._xmlns+tag)
 
     def nsstrip(self, tag):
